@@ -128,9 +128,7 @@ sub _can_release ($self) {
 
     # check master branch
     if ( !$id->{branch} || $id->{branch} ne 'master' ) {
-        say q[Git is not on the "master" branch.];
-
-        return;
+        return if P->term->prompt( q[Git is not on the "master" branch. Continue?], [qw[yes no]], enter => 1 ) eq 'no';
     }
 
     # check for uncommited changes
